==> mckit-0.6.30-cp310-cp310-manylinux_2_31_x86_64.whl: mckit/parser/common/composition_index.py <==
from __future__ import annotations

from collections.abc import Iterable

from mckit.material import Composition, Material
from mckit.utils.indexes import Index, NumberedItemNotFoundError


class DummyMaterial(Material):
    def __init__(
        self,
        name: int,
        *,
        density: float | None = None,
        concentration: float | None = None,
    ) -> None:
        assert (density is None) ^ (concentration is None), "Specify only one of the parameters"
        if density is None:
            # noinspection PyTypeChecker
            super().__init__(
                composition=DummyComposition(name), concentration=concentration * 1.0e24
            )
        else:
            super().__init__(composition=DummyComposition(name), density=density)


# noinspection PyTypeChecker
class DummyComposition(Composition):
    """To substitute composition when it's not found."""

    def __init__(self, name: int):
        super().__init__(name=name, weight=[(1001, 1.0)], comment="dummy")


def raise_on_absent_composition_strategy(name: int) -> DummyComposition | None:
    raise CompositionNotFoundError(name)


def dummy_on_absent_composition_strategy(name: int) -> DummyComposition | None:
    return DummyComposition(name)


class CompositionStrictIndex(Index):
    def __init__(self, **kwargs):
        super().__init__(raise_on_absent_composition_strategy, **kwargs)

    @classmethod
    def from_iterable(cls, items: Iterable[Composition]) -> CompositionStrictIndex:
        index = cls()
        index.update((c.name(), c) for c in items)
        return index


class CompositionDummyIndex(Index):
    def __init__(self, **kwargs):
        super().__init__(dummy_on_absent_composition_strategy, **kwargs)


class CompositionNotFoundError(NumberedItemNotFoundError):
    kind = "Composition"

==> mckit-0.8.2-cp310-cp310-manylinux_2_35_x86_64.whl: mckit/parser/common/composition_index.py <==
from __future__ import annotations

from collections.abc import Iterable

from mckit.material import Composition, Material
from mckit.utils.indexes import Index, NumberedItemNotFoundError


class DummyMaterial(Material):
    def __init__(
        self,
        name: int,
        *,
        density: float | None = None,
        concentration: float | None = None,
    ) -> None:
        if (density is None) == (concentration is None):
            msg = "Specify only one of the parameters"
            raise ValueError(msg)
        if density is None:
            # noinspection PyTypeChecker
            super().__init__(
                composition=DummyComposition(name), concentration=concentration * 1.0e24
            )
        else:
            super().__init__(composition=DummyComposition(name), density=density)


# noinspection PyTypeChecker
class DummyComposition(Composition):
    """To substitute composition when it's not found."""

    def __init__(self, name: int):
        super().__init__(name=name, weight=[(1001, 1.0)], comment="dummy")


def raise_on_absent_composition_strategy(name: int) -> DummyComposition | None:
    raise CompositionNotFoundError(name)


def dummy_on_absent_composition_strategy(name: int) -> DummyComposition | None:
    return DummyComposition(name)


class CompositionStrictIndex(Index):
    def __init__(self, **kwargs):
        super().__init__(raise_on_absent_composition_strategy, **kwargs)

    @classmethod
    def from_iterable(cls, items: Iterable[Composition]) -> CompositionStrictIndex:
        index = cls()
        index.update((c.name(), c) for c in items)
        return index


class CompositionDummyIndex(Index):
    def __init__(self, **kwargs):
        super().__init__(dummy_on_absent_composition_strategy, **kwargs)


class CompositionNotFoundError(NumberedItemNotFoundError):
    kind = "Composition"
